@@ -3,6 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -11,11 +13,10 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.9',
- 'BLDLIBRARY': '-L. -lpython3.9',
+ 'BINLIBDEST': '/usr/lib/python3.10',
+ 'BLDLIBRARY': '-L. -lpython3.10',
  'BLDSHARED': 'gcc -pthread -shared '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-fno-semantic-interposition '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -25,24 +26,22 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv8-a -O3 -pipe '
-           '-fstack-protector-strong -fno-plt',
+           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                     '-fno-plt -fno-semantic-interposition',
+                     '-fno-plt',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                      '-fno-semantic-interposition',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
                 "'--without-lto' '--enable-ipv6' '--with-system-expat' "
@@ -50,23 +49,23 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv8-a "
-                '-O3 -pipe -fstack-protector-strong -fno-plt '
-                "-fno-semantic-interposition' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
-                "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+                "-O3 -pipe -fstack-protector-strong -fno-plt' "
+                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
+                "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.9',
+ 'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.9.9/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.9.9/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.10.1/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.10.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.9',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.10 '
+             '/usr/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -88,10 +87,11 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-39-aarch64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-310-aarch64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
@@ -129,6 +129,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -181,6 +182,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -417,6 +419,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -425,7 +428,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -452,6 +454,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -512,6 +515,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -523,49 +527,47 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'aarch64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9 '
-                   '/usr/include/python3.9',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.10 '
+                   '/usr/include/python3.10',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.9',
+ 'INCLUDEPY': '/usr/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.9.so.1.0',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-            '-fno-semantic-interposition '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.9.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-fno-semantic-interposition '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'LDVERSION': '3.9',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.9',
+ 'LIBDEST': '/usr/lib/python3.10',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.9/config-3.9-aarch64-linux-gnu',
+ 'LIBPL': '/usr/lib/python3.10/config-3.10-aarch64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
@@ -577,7 +579,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.9',
+ 'MACHDESTLIB': '/usr/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -588,7 +590,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
+                   '_tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -601,8 +603,8 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'aarch64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"aarch64-linux-gnu\\"',
@@ -612,6 +614,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -621,8 +624,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
-                'Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
@@ -630,7 +632,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -643,14 +645,14 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv8-a -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
-                             '-fno-semantic-interposition -march=armv8-a -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fstack-protector-strong -fno-plt -march=armv8-a '
+                             '-O3 -pipe -fstack-protector-strong -fno-plt '
                              '-march=armv8-a -O3 -pipe '
                              '-fstack-protector-strong -fno-plt -std=c99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
@@ -662,9 +664,8 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv8-a -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -672,33 +673,30 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv8-a -O3 -pipe -fstack-protector-strong '
-                   '-fno-plt -fno-semantic-interposition -march=armv8-a -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -march=armv8-a -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-fno-plt -march=armv8-a -O3 -pipe -fstack-protector-strong '
+                   '-fno-plt -march=armv8-a -O3 -pipe -fstack-protector-strong '
+                   '-fno-plt -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-fno-semantic-interposition '
                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-               '-fno-semantic-interposition '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
-                        '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
                         '-fstack-protector-strong -fno-plt -march=armv8-a -O3 '
-                        '-pipe -fstack-protector-strong -fno-plt -std=c99 '
-                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-pipe -fstack-protector-strong -fno-plt '
+                        '-march=armv8-a -O3 -pipe -fstack-protector-strong '
+                        '-fno-plt -std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 '
@@ -711,7 +709,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.1',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -738,9 +736,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-39-aarch64-linux-gnu',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-310-aarch64-linux-gnu',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -749,36 +748,41 @@ build_time_vars = {'ABIFLAGS': '',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.9 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.1 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.9 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.1 ./python '
                './Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.9 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.9',
+ 'VERSION': '3.10',
+ 'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.9.9',
- 'abs_srcdir': '/build/python/src/Python-3.9.9',
+ 'abs_builddir': '/build/python/src/Python-3.10.1',
+ 'abs_srcdir': '/build/python/src/Python-3.10.1',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
